#========================================================================== #
#=
# Project Filename:    C:\travail\Prog\melia\doc\melia.last.dez             #
# Project Name:        b2i acadmique (version 3.5)                         #
# Author:              DD-JM                                                #
# DBMS:                MySQL 4                                              #
# Copyright:                                                                #
# Generated on:        26/07/2004 11:55:37                                  #
#========================================================================== #

#========================================================================== #
#  Tables                                                                   #
#========================================================================== #

CREATE TABLE eleves (
    eleve_id INTEGER NOT NULL AUTO_INCREMENT,
    nom VARCHAR(30) NOT NULL,
    prenom VARCHAR(25) NOT NULL,
    civil ENUM('M.','Mme','Mlle') NOT NULL DEFAULT 'M.',
    dnaiss VARCHAR(12) NOT NULL,
    ident_nat VARCHAR(32) DEFAULT 'NULL',
    imp_diplome VARCHAR(5),
    tag INTEGER DEFAULT 0,
    annee INTEGER NOT NULL,
    lastdisc TINYINT DEFAULT 0,
    compte_id INTEGER,
    classe_id INTEGER NOT NULL,
    etab_id INTEGER NOT NULL,
    CONSTRAINT PK_eleves PRIMARY KEY (eleve_id),
    UNIQUE KEY IDX_eleves_1(eleve_id),
    UNIQUE KEY IDX_eleves_2(eleve_id, compte_id)
);

CREATE TABLE profs (
    prof_id INTEGER NOT NULL AUTO_INCREMENT,
    nom VARCHAR(30) NOT NULL,
    prenom VARCHAR(25),
    civil ENUM('M.','Mme','Mlle') NOT NULL DEFAULT 'Mme',
    dnaiss VARCHAR(12) NOT NULL,
    ident_nat VARCHAR(32) DEFAULT 'NULL',
    admin INTEGER UNSIGNED NOT NULL DEFAULT 0,
    tag INTEGER DEFAULT 0,
    annee INTEGER NOT NULL,
    compte_id INTEGER,
    etab_id INTEGER NOT NULL,
    disc_id INTEGER NOT NULL,
    CONSTRAINT PK_profs PRIMARY KEY (prof_id),
    UNIQUE KEY IDX_profs_1(prof_id),
    UNIQUE KEY IDX_profs_2(prof_id, compte_id)
);

CREATE TABLE classes (
    classe_id INTEGER NOT NULL AUTO_INCREMENT,
    divcod VARCHAR(12) NOT NULL,
    divgro CHAR(1) DEFAULT 'D',
    etab_id INTEGER NOT NULL,
    CONSTRAINT PK_classes PRIMARY KEY (classe_id),
    UNIQUE KEY IDX_classes_1(classe_id)
);

CREATE TABLE lien_profs_classes (
    prof_id INTEGER NOT NULL,
    classe_id INTEGER NOT NULL,
    KEY idx_prof_id(prof_id)
);

CREATE TABLE items (
    item_id INTEGER NOT NULL AUTO_INCREMENT,
    brevet_no INTEGER,
    rub_no INTEGER NOT NULL,
    s_rub_no INTEGER,
    CONSTRAINT PK_items PRIMARY KEY (item_id),
    UNIQUE KEY IDX_items_1(item_id)
);

CREATE TABLE demandes (
    message_id INTEGER NOT NULL AUTO_INCREMENT,
    date DATETIME NOT NULL,
    comment TEXT,
    eleve_id INTEGER NOT NULL,
    item_id INTEGER NOT NULL,
    disc_id INTEGER NOT NULL DEFAULT 0,
    CONSTRAINT PK_demandes PRIMARY KEY (message_id),
    UNIQUE KEY IDX_demandes_1(message_id)
);

CREATE TABLE lien_profs_rubriques (
    prof_id INTEGER NOT NULL,
    rub_no INTEGER NOT NULL,
    KEY idx_prof_id(prof_id)
);

CREATE TABLE reponses (
    reponse_id INTEGER NOT NULL AUTO_INCREMENT,
    accord BOOL NOT NULL DEFAULT 0,
    date DATETIME,
    comment TEXT,
    message_id INTEGER,
    prof_id INTEGER NOT NULL,
    CONSTRAINT PK_reponses PRIMARY KEY (reponse_id),
    KEY idx_message_id(message_id)
);

CREATE TABLE resultats (
    resultat_id INTEGER NOT NULL AUTO_INCREMENT,
    date DATETIME NOT NULL,
    eleve_id INTEGER NOT NULL,
    item_id INTEGER NOT NULL,
    disc_id INTEGER NOT NULL DEFAULT 0,
    CONSTRAINT PK_resultats PRIMARY KEY (resultat_id),
    KEY idx_eleve_id(eleve_id)
);

CREATE TABLE rubriques (
    rub_no INTEGER NOT NULL,
    libelle TEXT,
    CONSTRAINT PK_rubriques PRIMARY KEY (rub_no),
    UNIQUE KEY IDX_rubriques_1(rub_no)
);

CREATE TABLE comptes (
    compte_id INTEGER NOT NULL AUTO_INCREMENT,
    login VARCHAR(16),
    mdp CHAR(32) NOT NULL DEFAULT '',
    statut ENUM('Eleve', 'Prof', 'Admin', 'Gest','Sadmin','Parent','Autre') NOT NULL,
    actif INTEGER DEFAULT 1,
    precdate INTEGER,
    nbsessions INTEGER DEFAULT 0,
    ip INTEGER,
    machinecliente VARCHAR(32),
    prof_id INTEGER,
    eleve_id INTEGER,
    etab_id INTEGER NOT NULL,
    CONSTRAINT PK_comptes PRIMARY KEY (compte_id)
);

CREATE TABLE libelles (
    item_id INTEGER NOT NULL,
    inst TEXT NOT NULL,
    base TEXT NOT NULL,
    CONSTRAINT PK_libelles PRIMARY KEY (item_id),
    UNIQUE KEY IDX_libelles_1(item_id)
);

CREATE TABLE disciplines (
    disc_id INTEGER NOT NULL,
    libelle VARCHAR(60),
    code_langue CHAR(2) DEFAULT 'Fr',
    CONSTRAINT PK_disciplines PRIMARY KEY (disc_id),
    UNIQUE KEY IDX_disciplines_1(disc_id)
)
 COMMENT='Liste obtenue du GEP par AP';

CREATE TABLE etablissements (
    etab_id INTEGER NOT NULL AUTO_INCREMENT,
    rne CHAR(8) NOT NULL,
    nom VARCHAR(50) NOT NULL,
    adresse VARCHAR(255),
    codepostal VARCHAR(6),
    ville VARCHAR(50),
    theme VARCHAR(20) NOT NULL DEFAULT 'standard',
    niveau ENUM('niv1','niv2','niv3','niv12','niv23','niv123') NOT NULL,
    nb_validations INTEGER NOT NULL DEFAULT 2,
    nbj_vie_demande INTEGER NOT NULL DEFAULT 30,
    nb_max_demandes INTEGER NOT NULL DEFAULT 2,
    nb_max_refus INTEGER DEFAULT 0,
    modele_login_e VARCHAR(20) NOT NULL DEFAULT 'ppp.nnn',
    modele_login_p VARCHAR(20) NOT NULL DEFAULT 'pn',
    mdp_eleve BOOL NOT NULL DEFAULT 1,
    mdp_prof BOOL NOT NULL DEFAULT 1,
    fiche_profs BOOL NOT NULL DEFAULT 1,
    stats_profs BOOL NOT NULL DEFAULT 1,
    pop_profs BOOL DEFAULT 1,
    valid_profs BOOL NOT NULL DEFAULT 1,
    result_profs BOOL NOT NULL DEFAULT 1,
    actif INTEGER DEFAULT 1,
    alert_message_vide TINYINT NOT NULL DEFAULT 0,
    CONSTRAINT PK_etablissements PRIMARY KEY (etab_id),
    UNIQUE (rne),
    UNIQUE KEY IDX_etablissements_1(etab_id)
);

CREATE TABLE _params_globaux (
    param_nom VARCHAR(32) NOT NULL,
    param_type ENUM('i','s','a') NOT NULL,
    param_val TEXT,
    param_desc VARCHAR(255),
    param_tag INTEGER NOT NULL DEFAULT 0,
    CONSTRAINT PK__params_globaux PRIMARY KEY (param_nom)
);

CREATE TABLE libelles_perso (
    item_id INTEGER NOT NULL,
    libelle TEXT NOT NULL,
    etab_id INTEGER NOT NULL
);

CREATE TABLE disc_gep (
    gep_id VARCHAR(8) NOT NULL,
    disc_id INTEGER NOT NULL,
    CONSTRAINT PK_disc_gep PRIMARY KEY (gep_id)
);

CREATE TABLE lien_eleves_disciplines (
    rang TINYINT,
    eleve_id INTEGER NOT NULL,
    disc_id INTEGER NOT NULL
)
 COMMENT='rang indique le n de langue vivante (le chiffre dans LV1, LV2, LV3)';

#========================================================================== #
#  Foreign Keys                                                             #
#========================================================================== #

ALTER TABLE eleves
    ADD CONSTRAINT classes_eleves FOREIGN KEY (classe_id) REFERENCES classes (classe_id);

ALTER TABLE eleves
    ADD CONSTRAINT etablissements_eleves FOREIGN KEY (etab_id) REFERENCES etablissements (etab_id);

ALTER TABLE profs
    ADD CONSTRAINT disciplines_profs FOREIGN KEY (disc_id) REFERENCES disciplines (disc_id);

ALTER TABLE profs
    ADD CONSTRAINT etablissements_profs FOREIGN KEY (etab_id) REFERENCES etablissements (etab_id);

ALTER TABLE classes
    ADD CONSTRAINT etablissements_classes FOREIGN KEY (etab_id) REFERENCES etablissements (etab_id);

ALTER TABLE lien_profs_classes
    ADD CONSTRAINT profs_lien_profs_classes FOREIGN KEY (prof_id) REFERENCES profs (prof_id);

ALTER TABLE lien_profs_classes
    ADD CONSTRAINT classes_lien_profs_classes FOREIGN KEY (classe_id) REFERENCES classes (classe_id);

ALTER TABLE items
    ADD CONSTRAINT rubriques_items FOREIGN KEY (rub_no) REFERENCES rubriques (rub_no);

ALTER TABLE demandes
    ADD CONSTRAINT eleves_demandes FOREIGN KEY (eleve_id) REFERENCES eleves (eleve_id);

ALTER TABLE demandes
    ADD CONSTRAINT items_demandes FOREIGN KEY (item_id) REFERENCES items (item_id);

ALTER TABLE demandes
    ADD FOREIGN KEY (disc_id) REFERENCES disciplines (disc_id);

ALTER TABLE lien_profs_rubriques
    ADD CONSTRAINT profs_lien_profs_rubriques FOREIGN KEY (prof_id) REFERENCES profs (prof_id);

ALTER TABLE lien_profs_rubriques
    ADD CONSTRAINT rubriques_lien_profs_rubriques FOREIGN KEY (rub_no) REFERENCES rubriques (rub_no);

ALTER TABLE reponses
    ADD CONSTRAINT demandes_reponses FOREIGN KEY (message_id) REFERENCES demandes (message_id);

ALTER TABLE reponses
    ADD CONSTRAINT profs_reponses FOREIGN KEY (prof_id) REFERENCES profs (prof_id);

ALTER TABLE resultats
    ADD CONSTRAINT eleves_resultats FOREIGN KEY (eleve_id) REFERENCES eleves (eleve_id);

ALTER TABLE resultats
    ADD CONSTRAINT items_resultats FOREIGN KEY (item_id) REFERENCES items (item_id);

ALTER TABLE resultats
    ADD FOREIGN KEY (disc_id) REFERENCES disciplines (disc_id);

ALTER TABLE comptes
    ADD CONSTRAINT profs_comptes FOREIGN KEY (compte_id,prof_id) REFERENCES profs (compte_id, prof_id);

ALTER TABLE comptes
    ADD CONSTRAINT eleves_comptes FOREIGN KEY (compte_id,eleve_id) REFERENCES eleves (compte_id, eleve_id);

ALTER TABLE comptes
    ADD CONSTRAINT etablissements_comptes FOREIGN KEY (etab_id) REFERENCES etablissements (etab_id);

ALTER TABLE libelles
    ADD CONSTRAINT items_libelles FOREIGN KEY (item_id) REFERENCES items (item_id);

ALTER TABLE libelles_perso
    ADD CONSTRAINT libelles_libelles_perso FOREIGN KEY (item_id) REFERENCES libelles (item_id);

ALTER TABLE libelles_perso
    ADD CONSTRAINT etablissements_libelles_perso FOREIGN KEY (etab_id) REFERENCES etablissements (etab_id);

ALTER TABLE disc_gep
    ADD CONSTRAINT disciplines_disc_gep FOREIGN KEY (disc_id) REFERENCES disciplines (disc_id);

ALTER TABLE lien_eleves_disciplines
    ADD FOREIGN KEY (eleve_id) REFERENCES eleves (eleve_id);

ALTER TABLE lien_eleves_disciplines
    ADD FOREIGN KEY (disc_id) REFERENCES disciplines (disc_id);
